summaryrefslogtreecommitdiffstats
path: root/src/declarative/util/qmlstate.cpp
diff options
context:
space:
mode:
authorMichael Brasser <michael.brasser@nokia.com>2009-09-25 04:45:44 (GMT)
committerMichael Brasser <michael.brasser@nokia.com>2009-09-25 04:45:44 (GMT)
commitc6090b6749c9f9bf002f999f808e456b74fea1bf (patch)
treebb568da34a86c0347fb27662a2e2633c1ed8059f /src/declarative/util/qmlstate.cpp
parenta8fa63eeb02773652befc138eef63c745f47684d (diff)
downloadQt-c6090b6749c9f9bf002f999f808e456b74fea1bf.zip
Qt-c6090b6749c9f9bf002f999f808e456b74fea1bf.tar.gz
Qt-c6090b6749c9f9bf002f999f808e456b74fea1bf.tar.bz2
Fix bug with signal overrides.
Diffstat (limited to 'src/declarative/util/qmlstate.cpp')
-rw-r--r--src/declarative/util/qmlstate.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/declarative/util/qmlstate.cpp b/src/declarative/util/qmlstate.cpp
index da7d429..3c85db7 100644
--- a/src/declarative/util/qmlstate.cpp
+++ b/src/declarative/util/qmlstate.cpp
@@ -360,8 +360,8 @@ void QmlState::apply(QmlStateGroup *group, QmlTransition *trans, QmlState *rever
}
}
if (!found)
- action.event->saveForwardBindings();
- //### do we ever need to do saveForwardBindings when found == true?
+ action.event->saveOriginals();
+ //### do we ever need to do saveOriginals when found == true?
} else {
action.fromBinding = action.property.binding();